@@ -38,6 +38,8 @@ my $PLATFORM_INFO = {
   "ubuntu-5.10"     => [ "Ubuntu Linux", "5.10", "Breezy" ],
   "ubuntu-6.06"     => [ "Ubuntu Linux", "6.06", "Dapper" ],
   "ubuntu-6.10"     => [ "Ubuntu Linux", "6.10", "Edgy" ],
+  "ubuntu-7.04"     => [ "Ubuntu Linux", "7.04", "Feisty" ],
+  "ubuntu-7.10"     => [ "Ubuntu Linux", "7.10", "Gutsy" ],
   "redhat-5.2"      => [ "Red Hat Linux", "5.2", "Apollo" ],
   "redhat-6.0"      => [ "Red Hat Linux", "6.0", "Hedwig" ],
   "redhat-6.1"      => [ "Red Hat Linux", "6.1", "Cartman" ],
@@ -92,6 +94,7 @@ my $PLATFORM_INFO = {
   "solaris-2.11"    => [ "Solaris / OpenSolaris", "2.11", "Nevada" ],
   "nexenta-1.0"     => [ "Nexenta GNU/Solaris", "1.0", "Ellate" ],
   "yellowdog-4.1"   => [ "Yellow Dog Linux", "4.1", "Sagitta" ],
+  "guadalinex-v4"   => [ "Guadalinex", "v4", "Toro" ],
 };
 
 sub get_platform_info
@@ -141,9 +144,11 @@ sub ensure_distro_map
      "ubuntu-5.10"      => "debian-3.0",
      "ubuntu-6.06"      => "debian-3.0",
      "ubuntu-6.10"      => "debian-3.0",
+     "ubuntu-7.10"      => "ubuntu-7.04",
      "vine-3.1"         => "vine-3.0",
      "vlos-1.2"         => "gentoo",
      "nexenta-1.0"      => "solaris-2.11",
+     "guadalinex-v4"    => "debian-3.0",
      );
 
   return $metamap{$distro} if ($metamap{$distro});
@@ -430,11 +435,15 @@ sub init
 {
   &get_system ();
 
-  if (!&get_cached_platform ())
-  {
+  # FIXME: need to figure out whether the underlying platform has
+  # been updated or changed, until now it's safer to ignore the cache,
+  # this function is called just once in all the executable lifecicle,
+  # so I don't expect any noticeable performance decrease.
+  #if (!&get_cached_platform ())
+  #{
     &guess ($self) if !$Utils::Backend::tool{"platform"};
     &cache_platform ();
-  }
+  #}
 }
 
 1;
